pub struct StatefulSetSpec {
pub replicas: Option<i32>,
pub selector: Option<LabelSelector>,
pub template: Option<PodTemplateSpec>,
pub volume_claim_templates: Vec<PersistentVolumeClaim>,
pub service_name: Option<String>,
pub pod_management_policy: Option<String>,
pub update_strategy: Option<StatefulSetUpdateStrategy>,
pub revision_history_limit: Option<i32>,
pub min_ready_seconds: Option<i32>,
pub persistent_volume_claim_retention_policy: Option<StatefulSetPersistentVolumeClaimRetentionPolicy>,
pub ordinals: Option<StatefulSetOrdinals>,
}Expand description
A StatefulSetSpec is the specification of a StatefulSet.
Fields
replicas: Option<i32>replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1. TODO: Consider a rename of this field. +optional
selector: Option<LabelSelector>selector is a label query over pods that should match the replica count. It must match the pod template’s labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
template: Option<PodTemplateSpec>template is the object that describes the pod that will be created if
insufficient replicas are detected. Each pod stamped out by the StatefulSet
will fulfill this Template, but have a unique identity from the rest
of the StatefulSet. Each pod will be named with the format
volume_claim_templates: Vec<PersistentVolumeClaim>volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name. TODO: Define the behavior if a claim already exists with the same name. +optional +listType=atomic
service_name: Option<String>serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where “pod-specific-string” is managed by the StatefulSet controller. +optional
pod_management_policy: Option<String>podManagementPolicy controls how pods are created during initial scale up,
when replacing pods on nodes, or when scaling down. The default policy is
OrderedReady, where pods are created in increasing order (pod-0, then
pod-1, etc) and the controller will wait until each pod is ready before
continuing. When scaling down, the pods are removed in the opposite order.
The alternative policy is Parallel which will create pods in parallel
to match the desired scale without waiting, and on scale down will delete
all pods at once.
+optional
update_strategy: Option<StatefulSetUpdateStrategy>updateStrategy indicates the StatefulSetUpdateStrategy that will be employed to update Pods in the StatefulSet when a revision is made to Template.
revision_history_limit: Option<i32>revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet’s revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10.
min_ready_seconds: Option<i32>Minimum number of seconds for which a newly created pod should be ready without any of its container crashing for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready) +optional
persistent_volume_claim_retention_policy: Option<StatefulSetPersistentVolumeClaimRetentionPolicy>persistentVolumeClaimRetentionPolicy describes the lifecycle of persistent volume claims created from volumeClaimTemplates. By default, all persistent volume claims are created as needed and retained until manually deleted. This policy allows the lifecycle to be altered, for example by deleting persistent volume claims when their stateful set is deleted, or when their pod is scaled down. +optional
ordinals: Option<StatefulSetOrdinals>ordinals controls the numbering of replica indices in a StatefulSet. The default ordinals behavior assigns a “0” index to the first replica and increments the index by one for each additional replica requested. +optional
Implementations
Sourceimpl StatefulSetSpec
impl StatefulSetSpec
Sourcepub fn replicas(&self) -> i32
pub fn replicas(&self) -> i32
Returns the value of replicas, or the default value if replicas is unset.
Sourcepub fn service_name(&self) -> &str
pub fn service_name(&self) -> &str
Returns the value of service_name, or the default value if service_name is unset.
Sourcepub fn pod_management_policy(&self) -> &str
pub fn pod_management_policy(&self) -> &str
Returns the value of pod_management_policy, or the default value if pod_management_policy is unset.
Sourcepub fn revision_history_limit(&self) -> i32
pub fn revision_history_limit(&self) -> i32
Returns the value of revision_history_limit, or the default value if revision_history_limit is unset.
Sourcepub fn min_ready_seconds(&self) -> i32
pub fn min_ready_seconds(&self) -> i32
Returns the value of min_ready_seconds, or the default value if min_ready_seconds is unset.