RollingUpdateStatefulSetStrategy

Struct RollingUpdateStatefulSetStrategy 

pub struct RollingUpdateStatefulSetStrategy {
    pub partition: Option<i32>,
    pub max_unavailable: Option<IntOrString>,
}
RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType.

Fields

partition: Option<i32>

Partition indicates the ordinal at which the StatefulSet should be partitioned for updates. During a rolling update, all pods from ordinal Replicas-1 to Partition are updated. All pods from ordinal Partition-1 to 0 remain untouched. This is helpful in being able to do a canary based deployment. The default value is 0.

max_unavailable: Option<IntOrString>

maxUnavailable is the maximum number of pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). Absolute number is calculated from percentage by rounding up. This can not be 0. Defaults to 1. This field is beta-level and is enabled by default. The field applies to all pods in the range 0 to Replicas-1. That means if there is any unavailable pod in the range 0 to Replicas-1, it will be counted towards MaxUnavailable. This setting might not be effective for the OrderedReady podManagementPolicy. That policy ensures pods are created and become ready one at a time.

+featureGate=MaxUnavailableStatefulSet +optional

Implementations

Source

impl RollingUpdateStatefulSetStrategy

pub fn partition(&self) -> i32

Returns the value of partition, or the default value if partition is unset.