pub struct StatefulSet {
pub metadata: Option<ObjectMeta>,
pub spec: Option<StatefulSetSpec>,
pub status: Option<StatefulSetStatus>,
}Expand description
DEPRECATED - This group version of StatefulSet is deprecated by apps/v1beta2/StatefulSet. See the release notes for more information. StatefulSet represents a set of pods with consistent identities. Identities are defined as:
- Network: A single stable DNS and hostname.
- Storage: As many VolumeClaims as requested.
The StatefulSet guarantees that a given network identity will always map to the same storage identity.
Fields
metadata: Option<ObjectMeta>+optional
spec: Option<StatefulSetSpec>Spec defines the desired identities of pods in this set. +optional
status: Option<StatefulSetStatus>Status is the current status of Pods in this StatefulSet. This data may be out of date by some window of time. +optional