pub struct StatefulSetUpdateStrategy {
pub type: Option<String>,
pub rolling_update: Option<RollingUpdateStatefulSetStrategy>,
}Expand description
StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy.
Fields
type: Option<String>Type indicates the type of the StatefulSetUpdateStrategy.
rolling_update: Option<RollingUpdateStatefulSetStrategy>RollingUpdate is used to communicate parameters when Type is RollingUpdateStatefulSetStrategyType.
Implementations