pub struct DaemonSetCondition {
pub type: Option<String>,
pub status: Option<String>,
pub last_transition_time: Option<Time>,
pub reason: Option<String>,
pub message: Option<String>,
}Expand description
DaemonSetCondition describes the state of a DaemonSet at a certain point.
Fields
type: Option<String>Type of DaemonSet condition.
status: Option<String>Status of the condition, one of True, False, Unknown.
last_transition_time: Option<Time>Last time the condition transitioned from one status to another. +optional
reason: Option<String>The reason for the condition’s last transition. +optional
message: Option<String>A human readable message indicating details about the transition. +optional
Implementations