pub struct ScaleStatus {
pub replicas: Option<i32>,
pub selector: BTreeMap<String, String>,
pub target_selector: Option<String>,
}Expand description
ScaleStatus represents the current status of a scale subresource.
Fields
replicas: Option<i32>actual number of observed instances of the scaled object.
selector: BTreeMap<String, String>selector is a label query over pods that should match the replicas count. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ +optional +mapType=atomic
target_selector: Option<String>label selector for pods that should match the replicas count. This is a serializated version of both map-based and more expressive set-based selectors. This is done to avoid introspection in the clients. The string will be in the same format as the query-param syntax. If the target type only supports map-based selectors, both this field and map-based selector field are populated. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors +optional
Implementations
Sourceimpl ScaleStatus
impl ScaleStatus