BoundObjectReference

Struct BoundObjectReference 

pub struct BoundObjectReference {
    pub kind: Option<String>,
    pub api_version: Option<String>,
    pub name: Option<String>,
    pub u_id: Option<String>,
}
BoundObjectReference is a reference to an object that a token is bound to.

Fields

kind: Option<String>

Kind of the referent. Valid kinds are ‘Pod’ and ‘Secret’. +optional

api_version: Option<String>

API version of the referent. +optional

name: Option<String>

Name of the referent. +optional

u_id: Option<String>

UID of the referent. +optional

Implementations

Source

impl BoundObjectReference

pub fn kind(&self) -> &str

Returns the value of kind, or the default value if kind is unset.

pub fn api_version(&self) -> &str

Returns the value of api_version, or the default value if api_version is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn u_id(&self) -> &str

Returns the value of u_id, or the default value if u_id is unset.