pub struct TokenRequest {
pub metadata: Option<ObjectMeta>,
pub spec: Option<TokenRequestSpec>,
pub status: Option<TokenRequestStatus>,
}Expand description
TokenRequest requests a token for a given service account.
Fields
metadata: Option<ObjectMeta>Standard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata +optional
spec: Option<TokenRequestSpec>Spec holds information about the request being evaluated
status: Option<TokenRequestStatus>Status is filled in by the server and indicates whether the token can be authenticated. +optional