TokenRequestSpec

Struct TokenRequestSpec 

pub struct TokenRequestSpec {
    pub audiences: Vec<String>,
    pub expiration_seconds: Option<i64>,
    pub bound_object_ref: Option<BoundObjectReference>,
}
TokenRequestSpec contains client provided parameters of a token request.

Fields

audiences: Vec<String>

Audiences are the intendend audiences of the token. A recipient of a token must identify themself with an identifier in the list of audiences of the token, and otherwise should reject the token. A token issued for multiple audiences may be used to authenticate against any of the audiences listed but implies a high degree of trust between the target audiences. +listType=atomic

expiration_seconds: Option<i64>

ExpirationSeconds is the requested duration of validity of the request. The token issuer may return a token with a different validity duration so a client needs to check the ‘expiration’ field in a response. +optional

bound_object_ref: Option<BoundObjectReference>

BoundObjectRef is a reference to an object that the token will be bound to. The token will only be valid for as long as the bound object exists. NOTE: The API server’s TokenReview endpoint will validate the BoundObjectRef, but other audiences may not. Keep ExpirationSeconds small if you want prompt revocation. +optional

Implementations

Source

impl TokenRequestSpec

pub fn expiration_seconds(&self) -> i64

Returns the value of expiration_seconds, or the default value if expiration_seconds is unset.