TokenRequestStatus

Struct TokenRequestStatus 

pub struct TokenRequestStatus {
    pub token: Option<String>,
    pub expiration_timestamp: Option<Time>,
}
TokenRequestStatus is the result of a token request.

Fields

token: Option<String>

Token is the opaque bearer token.

expiration_timestamp: Option<Time>

ExpirationTimestamp is the time of expiration of the returned token.

Implementations

Source

impl TokenRequestStatus

pub fn token(&self) -> &str

Returns the value of token, or the default value if token is unset.