pub struct NonResourceRule {
pub verbs: Vec<String>,
pub non_resource_ur_ls: Vec<String>,
}Expand description
NonResourceRule holds information that describes a rule for the non-resource
Fields
verbs: Vec<String>Verb is a list of kubernetes non-resource API verbs, like: get, post, put, delete, patch, head, options. “*” means all. +listType=atomic
non_resource_ur_ls: Vec<String>NonResourceURLs is a set of partial urls that a user should have access to. s are allowed, but only as the full, final step in the path. “” means all. +optional +listType=atomic