pub struct PodFailurePolicyOnPodConditionsPattern {
pub type: Option<String>,
pub status: Option<String>,
}Expand description
PodFailurePolicyOnPodConditionsPattern describes a pattern for matching an actual pod condition type.
Fields
type: Option<String>Specifies the required Pod condition type. To match a pod condition it is required that specified type equals the pod condition type.
status: Option<String>Specifies the required Pod condition status. To match a pod condition it is required that the specified status equals the pod condition status. Defaults to True. +optional
Implementations