pub struct FileKeySelector {
pub volume_name: Option<String>,
pub path: Option<String>,
pub key: Option<String>,
pub optional: Option<bool>,
}Expand description
FileKeySelector selects a key of the env file. +structType=atomic
Fields
volume_name: Option<String>The name of the volume mount containing the env file. +required
path: Option<String>The path within the volume from which to select the file. Must be relative and may not contain the ‘..’ path or start with ‘..’. +required
key: Option<String>The key within the env file. An invalid key will prevent the pod from starting. The keys defined within a source may consist of any printable ASCII characters except ‘=’. During Alpha stage of the EnvFiles feature gate, the key size is limited to 128 characters. +required
optional: Option<bool>Specify whether the file or its key must be defined. If the file or key does not exist, then the env var is not published. If optional is set to true and the specified key does not exist, the environment variable will not be set in the Pod’s containers.
If optional is set to false and the specified key does not exist, an error will be returned during Pod creation. +optional +default=false
Implementations
Sourceimpl FileKeySelector
impl FileKeySelector
Sourcepub fn volume_name(&self) -> &str
pub fn volume_name(&self) -> &str
Returns the value of volume_name, or the default value if volume_name is unset.