PriorityLevelConfigurationSpec

Struct PriorityLevelConfigurationSpec 

pub struct PriorityLevelConfigurationSpec {
    pub type: Option<String>,
    pub limited: Option<LimitedPriorityLevelConfiguration>,
    pub exempt: Option<ExemptPriorityLevelConfiguration>,
}
PriorityLevelConfigurationSpec specifies the configuration of a priority level. +union

Fields

type: Option<String>

type indicates whether this priority level is subject to limitation on request execution. A value of "Exempt" means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels. A value of "Limited" means that (a) requests of this priority level are subject to limits and (b) some of the server’s limited capacity is made available exclusively to this priority level. Required. +unionDiscriminator

limited: Option<LimitedPriorityLevelConfiguration>

limited specifies how requests are handled for a Limited priority level. This field must be non-empty if and only if type is "Limited". +optional

exempt: Option<ExemptPriorityLevelConfiguration>

exempt specifies how requests are handled for an exempt priority level. This field MUST be empty if type is "Limited". This field MAY be non-empty if type is "Exempt". If empty and type is "Exempt" then the default values for ExemptPriorityLevelConfiguration apply. +optional

Implementations

Source

impl PriorityLevelConfigurationSpec

pub fn type(&self) -> &str

Returns the value of type, or the default value if type is unset.