ExemptPriorityLevelConfiguration

Struct ExemptPriorityLevelConfiguration 

pub struct ExemptPriorityLevelConfiguration {
    pub nominal_concurrency_shares: Option<i32>,
    pub lendable_percent: Option<i32>,
}
ExemptPriorityLevelConfiguration describes the configurable aspects of the handling of exempt requests. In the mandatory exempt configuration object the values in the fields here can be modified by authorized users, unlike the rest of the spec.

Fields

nominal_concurrency_shares: Option<i32>

nominalConcurrencyShares (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats nominally reserved for this priority level. This DOES NOT limit the dispatching from this priority level but affects the other priority levels through the borrowing mechanism. The server’s concurrency limit (ServerCL) is divided among all the priority levels in proportion to their NCS values:

NominalCL(i) = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)

Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. This field has a default value of zero. +optional

lendable_percent: Option<i32>

lendablePercent prescribes the fraction of the level’s NominalCL that can be borrowed by other priority levels. This value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level’s LendableConcurrencyLimit (LendableCL), is defined as follows.

LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )

+optional

Implementations

Source

impl ExemptPriorityLevelConfiguration

pub fn nominal_concurrency_shares(&self) -> i32

Returns the value of nominal_concurrency_shares, or the default value if nominal_concurrency_shares is unset.

pub fn lendable_percent(&self) -> i32

Returns the value of lendable_percent, or the default value if lendable_percent is unset.