pub struct QueuingConfiguration {
pub queues: Option<i32>,
pub hand_size: Option<i32>,
pub queue_length_limit: Option<i32>,
}Expand description
QueuingConfiguration holds the configuration parameters for queuing
Fields
queues: Option<i32>queues is the number of queues for this priority level. The
queues exist independently at each apiserver. The value must be
positive. Setting it to 1 effectively precludes
shufflesharding and thus makes the distinguisher method of
associated flow schemas irrelevant. This field has a default
value of 64.
+optional
hand_size: Option<i32>handSize is a small positive number that configures the
shuffle sharding of requests into queues. When enqueuing a request
at this priority level the request’s flow identifier (a string
pair) is hashed and the hash value is used to shuffle the list
of queues and deal a hand of the size specified here. The
request is put into one of the shortest queues in that hand.
handSize must be no larger than queues, and should be
significantly smaller (so that a few heavy flows do not
saturate most of the queues). See the user-facing
documentation for more extensive guidance on setting this
field. This field has a default value of 8.
+optional
queue_length_limit: Option<i32>queueLengthLimit is the maximum number of requests allowed to
be waiting in a given queue of this priority level at a time;
excess requests are rejected. This value must be positive. If
not specified, it will be defaulted to 50.
+optional
Implementations
Sourceimpl QueuingConfiguration
impl QueuingConfiguration
Sourcepub fn queues(&self) -> i32
pub fn queues(&self) -> i32
Returns the value of queues, or the default value if queues is unset.
Sourcepub fn hand_size(&self) -> i32
pub fn hand_size(&self) -> i32
Returns the value of hand_size, or the default value if hand_size is unset.
Sourcepub fn queue_length_limit(&self) -> i32
pub fn queue_length_limit(&self) -> i32
Returns the value of queue_length_limit, or the default value if queue_length_limit is unset.