pub struct RuntimeClass {
pub metadata: Option<ObjectMeta>,
pub spec: Option<RuntimeClassSpec>,
}Expand description
RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are (currently) manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod. For more details, see https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class
Fields
metadata: Option<ObjectMeta>More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata +optional
spec: Option<RuntimeClassSpec>spec represents specification of the RuntimeClass More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status