pub struct Overhead {
pub pod_fixed: BTreeMap<String, Quantity>,
}Expand description
Overhead structure represents the resource overhead associated with running a pod.
Fields
pod_fixed: BTreeMap<String, Quantity>podFixed represents the fixed resource overhead associated with running a pod. +optional