pub struct DeviceAllocationConfiguration {
pub source: Option<String>,
pub requests: Vec<String>,
pub device_configuration: Option<DeviceConfiguration>,
}Expand description
DeviceAllocationConfiguration gets embedded in an AllocationResult.
Fields
source: Option<String>Source records whether the configuration comes from a class and thus is not something that a normal user would have been able to set or from a claim.
+required +k8s:required
requests: Vec<String>Requests lists the names of requests where the configuration applies. If empty, its applies to all requests.
References to subrequests must include the name of the main request
and may include the subrequest using the format
+optional +listType=atomic +k8s:optional +k8s:listType=atomic +k8s:unique=set +k8s:maxItems=32
device_configuration: Option<DeviceConfiguration>Implementations