pub struct DeviceConfiguration {
pub opaque: Option<OpaqueDeviceConfiguration>,
}Expand description
DeviceConfiguration must have exactly one field set. It gets embedded inline in some other structs which have other fields, so field names must not conflict with those.
Fields
opaque: Option<OpaqueDeviceConfiguration>Opaque provides driver-specific configuration parameters.
+optional +oneOf=ConfigurationType +k8s:optional