ResourcePool

Struct ResourcePool 

pub struct ResourcePool {
    pub name: Option<String>,
    pub generation: Option<i64>,
    pub resource_slice_count: Option<i64>,
}
ResourcePool describes the pool that ResourceSlices belong to.

Fields

name: Option<String>

Name is used to identify the pool. For node-local devices, this is often the node name, but this is not required.

It must not be longer than 253 characters and must consist of one or more DNS sub-domains separated by slashes. This field is immutable.

+required

generation: Option<i64>

Generation tracks the change in a pool over time. Whenever a driver changes something about one or more of the resources in a pool, it must change the generation in all ResourceSlices which are part of that pool. Consumers of ResourceSlices should only consider resources from the pool with the highest generation number. The generation may be reset by drivers, which should be fine for consumers, assuming that all ResourceSlices in a pool are updated to match or deleted.

Combined with ResourceSliceCount, this mechanism enables consumers to detect pools which are comprised of multiple ResourceSlices and are in an incomplete state.

+required

resource_slice_count: Option<i64>

ResourceSliceCount is the total number of ResourceSlices in the pool at this generation number. Must be greater than zero.

Consumers can use this to check whether they have seen all ResourceSlices belonging to the same pool.

+required

Implementations

Source

impl ResourcePool

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn generation(&self) -> i64

Returns the value of generation, or the default value if generation is unset.

pub fn resource_slice_count(&self) -> i64

Returns the value of resource_slice_count, or the default value if resource_slice_count is unset.