BasicDevice

Struct BasicDevice 

pub struct BasicDevice {
    pub attributes: BTreeMap<String, DeviceAttribute>,
    pub capacity: BTreeMap<String, DeviceCapacity>,
    pub consumes_counters: Vec<DeviceCounterConsumption>,
    pub node_name: Option<String>,
    pub node_selector: Option<NodeSelector>,
    pub all_nodes: Option<bool>,
    pub taints: Vec<DeviceTaint>,
    pub binds_to_node: Option<bool>,
    pub binding_conditions: Vec<String>,
    pub binding_failure_conditions: Vec<String>,
    pub allow_multiple_allocations: Option<bool>,
}
BasicDevice defines one device instance.

Fields

attributes: BTreeMap<String, DeviceAttribute>

Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.

The maximum number of attributes and capacities combined is 32.

+optional

capacity: BTreeMap<String, DeviceCapacity>

Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.

The maximum number of attributes and capacities combined is 32.

+optional

consumes_counters: Vec<DeviceCounterConsumption>

ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.

There can only be a single entry per counterSet.

The maximum number of device counter consumptions per device is 2.

+optional +k8s:optional +listType=atomic +k8s:listType=atomic +k8s:unique=map +k8s:listMapKey=counterSet +featureGate=DRAPartitionableDevices +k8s:maxItems=2

node_name: Option<String>

NodeName identifies the node where the device is available.

Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.

+optional +oneOf=DeviceNodeSelection +featureGate=DRAPartitionableDevices

node_selector: Option<NodeSelector>

NodeSelector defines the nodes where the device is available.

Must use exactly one term.

Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.

+optional +oneOf=DeviceNodeSelection

all_nodes: Option<bool>

AllNodes indicates that all nodes have access to the device.

Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.

+optional +oneOf=DeviceNodeSelection +featureGate=DRAPartitionableDevices

taints: Vec<DeviceTaint>

If specified, these are the driver-defined taints.

The maximum number of taints is 16. If taints are set for any device in a ResourceSlice, then the maximum number of allowed devices per ResourceSlice is 64 instead of 128.

This is an alpha field and requires enabling the DRADeviceTaints feature gate.

+optional +listType=atomic +featureGate=DRADeviceTaints

binds_to_node: Option<bool>

BindsToNode indicates if the usage of an allocation involving this device has to be limited to exactly the node that was chosen when allocating the claim. If set to true, the scheduler will set the ResourceClaim.Status.Allocation.NodeSelector to match the node where the allocation was made.

This is an alpha field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.

+optional +featureGate=DRADeviceBindingConditions,DRAResourceClaimDeviceStatus

binding_conditions: Vec<String>

BindingConditions defines the conditions for proceeding with binding. All of these conditions must be set in the per-device status conditions with a value of True to proceed with binding the pod to the node while scheduling the pod.

The maximum number of binding conditions is 4.

The conditions must be a valid condition type string.

This is an alpha field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.

+optional +listType=atomic +featureGate=DRADeviceBindingConditions,DRAResourceClaimDeviceStatus +k8s:optional +k8s:maxItems=4

binding_failure_conditions: Vec<String>

BindingFailureConditions defines the conditions for binding failure. They may be set in the per-device status conditions. If any is true, a binding failure occurred.

The maximum number of binding failure conditions is 4.

The conditions must be a valid condition type string.

This is an alpha field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.

+optional +listType=atomic +featureGate=DRADeviceBindingConditions,DRAResourceClaimDeviceStatus +k8s:optional +k8s:maxItems=4

allow_multiple_allocations: Option<bool>

AllowMultipleAllocations marks whether the device is allowed to be allocated to multiple DeviceRequests.

If AllowMultipleAllocations is set to true, the device can be allocated more than once, and all of its capacity is consumable, regardless of whether the requestPolicy is defined or not.

+optional +featureGate=DRAConsumableCapacity

Implementations

Source

impl BasicDevice

pub fn node_name(&self) -> &str

Returns the value of node_name, or the default value if node_name is unset.

pub fn all_nodes(&self) -> bool

Returns the value of all_nodes, or the default value if all_nodes is unset.

pub fn binds_to_node(&self) -> bool

Returns the value of binds_to_node, or the default value if binds_to_node is unset.

pub fn allow_multiple_allocations(&self) -> bool

Returns the value of allow_multiple_allocations, or the default value if allow_multiple_allocations is unset.