pub struct CounterSet {
pub name: Option<String>,
pub counters: BTreeMap<String, Counter>,
}Expand description
CounterSet defines a named set of counters that are available to be used by devices defined in the ResourcePool.
The counters are not allocatable by themselves, but can be referenced by devices. When a device is allocated, the portion of counters it uses will no longer be available for use by other devices.
Fields
name: Option<String>Name defines the name of the counter set. It must be a DNS label.
+required +k8s:required +k8s:format=k8s-short-name
counters: BTreeMap<String, Counter>Counters defines the set of counters for this CounterSet The name of each counter must be unique in that set and must be a DNS label.
The maximum number of counters is 32.
+required
Implementations