pub struct TypedLocalObjectReference {
pub api_group: Option<String>,
pub kind: Option<String>,
pub name: Option<String>,
}Expand description
TypedLocalObjectReference allows to reference typed object inside the same namespace.
Fields
api_group: Option<String>APIGroup is the group for the resource being referenced. If APIGroup is empty, the specified Kind must be in the core API group. For any other third-party types, setting APIGroup is required. It must be a DNS subdomain.
+optional
kind: Option<String>Kind is the type of resource being referenced. It must be a path segment name.
+required
name: Option<String>Name is the name of resource being referenced. It must be a path segment name.
+required
Implementations