VolumeAttributesClass

Struct VolumeAttributesClass 

pub struct VolumeAttributesClass {
    pub metadata: Option<ObjectMeta>,
    pub driver_name: Option<String>,
    pub parameters: BTreeMap<String, String>,
}
VolumeAttributesClass represents a specification of mutable volume attributes defined by the CSI driver. The class can be specified during dynamic provisioning of PersistentVolumeClaims, and changed in the PersistentVolumeClaim spec after provisioning.

Fields

metadata: Option<ObjectMeta>driver_name: Option<String>

Name of the CSI driver This field is immutable.

parameters: BTreeMap<String, String>

parameters hold volume attributes defined by the CSI driver. These values are opaque to the Kubernetes and are passed directly to the CSI driver. The underlying storage provider supports changing these attributes on an existing volume, however the parameters field itself is immutable. To invoke a volume update, a new VolumeAttributesClass should be created with new parameters, and the PersistentVolumeClaim should be updated to reference the new VolumeAttributesClass.

This field is required and must contain at least one key/value pair. The keys cannot be empty, and the maximum number of parameters is 512, with a cumulative max size of 256K. If the CSI driver rejects invalid parameters, the target PersistentVolumeClaim will be set to an “Infeasible” state in the modifyVolumeStatus field.

Implementations

Source

impl VolumeAttributesClass

pub fn driver_name(&self) -> &str

Returns the value of driver_name, or the default value if driver_name is unset.