VolumeError

Struct VolumeError 

pub struct VolumeError {
    pub time: Option<Time>,
    pub message: Option<String>,
    pub error_code: Option<i32>,
}
VolumeError captures an error encountered during a volume operation.

Fields

time: Option<Time>

time represents the time the error was encountered. +optional

message: Option<String>

message represents the error encountered during Attach or Detach operation. This string may be logged, so it should not contain sensitive information. +optional

error_code: Option<i32>

errorCode is a numeric gRPC code representing the error encountered during Attach or Detach operations.

This is an optional, beta field that requires the MutableCSINodeAllocatableCount feature gate being enabled to be set.

+featureGate=MutableCSINodeAllocatableCount +optional

Implementations

Source

impl VolumeError

pub fn message(&self) -> &str

Returns the value of message, or the default value if message is unset.

pub fn error_code(&self) -> i32

Returns the value of error_code, or the default value if error_code is unset.