pub struct TypeMeta {
pub api_version: Option<String>,
pub kind: Option<String>,
}Expand description
TypeMeta is shared by all top level objects. The proper way to use it is to inline it in your type, like this:
type MyAwesomeAPIObject struct {
runtime.TypeMeta `json:",inline"`
... // other fields
}func (obj *MyAwesomeAPIObject) SetGroupVersionKind(gvk *metav1.GroupVersionKind) { metav1.UpdateTypeMeta(obj,gvk) }; GroupVersionKind() *GroupVersionKind
TypeMeta is provided here for convenience. You may use it directly from this package or define your own with the same fields.
+k8s:deepcopy-gen=false +protobuf=true +k8s:openapi-gen=true
Fields
api_version: Option<String>+optional
kind: Option<String>+optional
Implementations