pub struct DaemonSetSpec {
pub selector: Option<LabelSelector>,
pub template: Option<PodTemplateSpec>,
pub update_strategy: Option<DaemonSetUpdateStrategy>,
pub min_ready_seconds: Option<i32>,
pub revision_history_limit: Option<i32>,
}Expand description
DaemonSetSpec is the specification of a daemon set.
Fields
selector: Option<LabelSelector>A label query over pods that are managed by the daemon set. Must match in order to be controlled. It must match the pod template’s labels. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors
template: Option<PodTemplateSpec>An object that describes the pod that will be created. The DaemonSet will create exactly one copy of this pod on every node that matches the template’s node selector (or on every node if no node selector is specified). The only allowed template.spec.restartPolicy value is “Always”. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#pod-template
update_strategy: Option<DaemonSetUpdateStrategy>An update strategy to replace existing DaemonSet pods with new pods. +optional
min_ready_seconds: Option<i32>The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready). +optional
revision_history_limit: Option<i32>The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10. +optional
Implementations
Sourceimpl DaemonSetSpec
impl DaemonSetSpec
Sourcepub fn min_ready_seconds(&self) -> i32
pub fn min_ready_seconds(&self) -> i32
Returns the value of min_ready_seconds, or the default value if min_ready_seconds is unset.
Sourcepub fn revision_history_limit(&self) -> i32
pub fn revision_history_limit(&self) -> i32
Returns the value of revision_history_limit, or the default value if revision_history_limit is unset.