pub struct DaemonSetStatus {
pub current_number_scheduled: Option<i32>,
pub number_misscheduled: Option<i32>,
pub desired_number_scheduled: Option<i32>,
pub number_ready: Option<i32>,
pub observed_generation: Option<i64>,
pub updated_number_scheduled: Option<i32>,
pub number_available: Option<i32>,
pub number_unavailable: Option<i32>,
pub collision_count: Option<i32>,
pub conditions: Vec<DaemonSetCondition>,
}Expand description
DaemonSetStatus represents the current status of a daemon set.
Fields
current_number_scheduled: Option<i32>The number of nodes that are running at least 1 daemon pod and are supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
number_misscheduled: Option<i32>The number of nodes that are running the daemon pod, but are not supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
desired_number_scheduled: Option<i32>The total number of nodes that should be running the daemon pod (including nodes correctly running the daemon pod). More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/
number_ready: Option<i32>numberReady is the number of nodes that should be running the daemon pod and have one or more of the daemon pod running with a Ready Condition.
observed_generation: Option<i64>The most recent generation observed by the daemon set controller. +optional
updated_number_scheduled: Option<i32>The total number of nodes that are running updated daemon pod +optional
number_available: Option<i32>The number of nodes that should be running the daemon pod and have one or more of the daemon pod running and available (ready for at least spec.minReadySeconds) +optional
The number of nodes that should be running the daemon pod and have none of the daemon pod running and available (ready for at least spec.minReadySeconds) +optional
collision_count: Option<i32>Count of hash collisions for the DaemonSet. The DaemonSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision. +optional
conditions: Vec<DaemonSetCondition>Represents the latest available observations of a DaemonSet’s current state. +optional +patchMergeKey=type +patchStrategy=merge +listType=map +listMapKey=type
Implementations
Sourceimpl DaemonSetStatus
impl DaemonSetStatus
Sourcepub fn current_number_scheduled(&self) -> i32
pub fn current_number_scheduled(&self) -> i32
Returns the value of current_number_scheduled, or the default value if current_number_scheduled is unset.
Sourcepub fn number_misscheduled(&self) -> i32
pub fn number_misscheduled(&self) -> i32
Returns the value of number_misscheduled, or the default value if number_misscheduled is unset.
Sourcepub fn desired_number_scheduled(&self) -> i32
pub fn desired_number_scheduled(&self) -> i32
Returns the value of desired_number_scheduled, or the default value if desired_number_scheduled is unset.
Sourcepub fn number_ready(&self) -> i32
pub fn number_ready(&self) -> i32
Returns the value of number_ready, or the default value if number_ready is unset.
Sourcepub fn observed_generation(&self) -> i64
pub fn observed_generation(&self) -> i64
Returns the value of observed_generation, or the default value if observed_generation is unset.
Sourcepub fn updated_number_scheduled(&self) -> i32
pub fn updated_number_scheduled(&self) -> i32
Returns the value of updated_number_scheduled, or the default value if updated_number_scheduled is unset.
Sourcepub fn number_available(&self) -> i32
pub fn number_available(&self) -> i32
Returns the value of number_available, or the default value if number_available is unset.
Returns the value of number_unavailable, or the default value if number_unavailable is unset.
Sourcepub fn collision_count(&self) -> i32
pub fn collision_count(&self) -> i32
Returns the value of collision_count, or the default value if collision_count is unset.