pub struct StatefulSetStatus {
pub observed_generation: Option<i64>,
pub replicas: Option<i32>,
pub ready_replicas: Option<i32>,
pub current_replicas: Option<i32>,
pub updated_replicas: Option<i32>,
pub current_revision: Option<String>,
pub update_revision: Option<String>,
pub collision_count: Option<i32>,
pub conditions: Vec<StatefulSetCondition>,
pub available_replicas: Option<i32>,
}Expand description
StatefulSetStatus represents the current state of a StatefulSet.
Fields
observed_generation: Option<i64>observedGeneration is the most recent generation observed for this StatefulSet. It corresponds to the StatefulSet’s generation, which is updated on mutation by the API Server. +optional
replicas: Option<i32>replicas is the number of Pods created by the StatefulSet controller.
ready_replicas: Option<i32>readyReplicas is the number of pods created for this StatefulSet with a Ready Condition.
current_replicas: Option<i32>currentReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by currentRevision.
updated_replicas: Option<i32>updatedReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by updateRevision.
current_revision: Option<String>currentRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [0,currentReplicas).
update_revision: Option<String>updateRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [replicas-updatedReplicas,replicas)
collision_count: Option<i32>collisionCount is the count of hash collisions for the StatefulSet. The StatefulSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision. +optional
conditions: Vec<StatefulSetCondition>Represents the latest available observations of a statefulset’s current state. +optional +patchMergeKey=type +patchStrategy=merge +listType=map +listMapKey=type
available_replicas: Option<i32>Total number of available pods (ready for at least minReadySeconds) targeted by this statefulset. +optional
Implementations
Sourceimpl StatefulSetStatus
impl StatefulSetStatus
Sourcepub fn observed_generation(&self) -> i64
pub fn observed_generation(&self) -> i64
Returns the value of observed_generation, or the default value if observed_generation is unset.
Sourcepub fn replicas(&self) -> i32
pub fn replicas(&self) -> i32
Returns the value of replicas, or the default value if replicas is unset.
Sourcepub fn ready_replicas(&self) -> i32
pub fn ready_replicas(&self) -> i32
Returns the value of ready_replicas, or the default value if ready_replicas is unset.
Sourcepub fn current_replicas(&self) -> i32
pub fn current_replicas(&self) -> i32
Returns the value of current_replicas, or the default value if current_replicas is unset.
Sourcepub fn updated_replicas(&self) -> i32
pub fn updated_replicas(&self) -> i32
Returns the value of updated_replicas, or the default value if updated_replicas is unset.
Sourcepub fn current_revision(&self) -> &str
pub fn current_revision(&self) -> &str
Returns the value of current_revision, or the default value if current_revision is unset.
Sourcepub fn update_revision(&self) -> &str
pub fn update_revision(&self) -> &str
Returns the value of update_revision, or the default value if update_revision is unset.
Sourcepub fn collision_count(&self) -> i32
pub fn collision_count(&self) -> i32
Returns the value of collision_count, or the default value if collision_count is unset.
Sourcepub fn available_replicas(&self) -> i32
pub fn available_replicas(&self) -> i32
Returns the value of available_replicas, or the default value if available_replicas is unset.