pub struct ResourceRule {
pub verbs: Vec<String>,
pub api_groups: Vec<String>,
pub resources: Vec<String>,
pub resource_names: Vec<String>,
}Expand description
ResourceRule is the list of actions the subject is allowed to perform on resources. The list ordering isn’t significant, may contain duplicates, and possibly be incomplete.
Fields
verbs: Vec<String>Verb is a list of kubernetes resource API verbs, like: get, list, watch, create, update, delete, proxy. “*” means all. +listType=atomic
api_groups: Vec<String>APIGroups is the name of the APIGroup that contains the resources. If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed. “*” means all. +optional +listType=atomic
resources: Vec<String>Resources is a list of resources this rule applies to. “” means all in the specified apiGroups. “/foo” represents the subresource ‘foo’ for all resources in the specified apiGroups. +optional +listType=atomic
resource_names: Vec<String>ResourceNames is an optional white list of names that the rule applies to. An empty set means that everything is allowed. “*” means all. +optional +listType=atomic