pub struct ContainerExtendedResourceRequest {
pub container_name: Option<String>,
pub resource_name: Option<String>,
pub request_name: Option<String>,
}Expand description
ContainerExtendedResourceRequest has the mapping of container name, extended resource name to the device request name.
Fields
container_name: Option<String>The name of the container requesting resources.
resource_name: Option<String>The name of the extended resource in that container which gets backed by DRA.
request_name: Option<String>The name of the request in the special ResourceClaim which corresponds to the extended resource.
Implementations
Sourceimpl ContainerExtendedResourceRequest
impl ContainerExtendedResourceRequest
Sourcepub fn container_name(&self) -> &str
pub fn container_name(&self) -> &str
Returns the value of container_name, or the default value if container_name is unset.
Sourcepub fn resource_name(&self) -> &str
pub fn resource_name(&self) -> &str
Returns the value of resource_name, or the default value if resource_name is unset.
Sourcepub fn request_name(&self) -> &str
pub fn request_name(&self) -> &str
Returns the value of request_name, or the default value if request_name is unset.