pub struct PodExtendedResourceClaimStatus {
pub request_mappings: Vec<ContainerExtendedResourceRequest>,
pub resource_claim_name: Option<String>,
}Expand description
PodExtendedResourceClaimStatus is stored in the PodStatus for the extended resource requests backed by DRA. It stores the generated name for the corresponding special ResourceClaim created by the scheduler.
Fields
request_mappings: Vec<ContainerExtendedResourceRequest>RequestMappings identifies the mapping of <container, extended resource backed by DRA> to device request in the generated ResourceClaim. +listType=atomic
resource_claim_name: Option<String>ResourceClaimName is the name of the ResourceClaim that was generated for the Pod in the namespace of the Pod.
Implementations
Sourceimpl PodExtendedResourceClaimStatus
impl PodExtendedResourceClaimStatus
Sourcepub fn resource_claim_name(&self) -> &str
pub fn resource_claim_name(&self) -> &str
Returns the value of resource_claim_name, or the default value if resource_claim_name is unset.