WorkloadReference

Struct WorkloadReference 

pub struct WorkloadReference {
    pub name: Option<String>,
    pub pod_group: Option<String>,
    pub pod_group_replica_key: Option<String>,
}
WorkloadReference identifies the Workload object and PodGroup membership that a Pod belongs to. The scheduler uses this information to apply workload-aware scheduling semantics.

Fields

name: Option<String>

Name defines the name of the Workload object this Pod belongs to. Workload must be in the same namespace as the Pod. If it doesn’t match any existing Workload, the Pod will remain unschedulable until a Workload object is created and observed by the kube-scheduler. It must be a DNS subdomain.

+required

pod_group: Option<String>

PodGroup is the name of the PodGroup within the Workload that this Pod belongs to. If it doesn’t match any existing PodGroup within the Workload, the Pod will remain unschedulable until the Workload object is recreated and observed by the kube-scheduler. It must be a DNS label.

+required

pod_group_replica_key: Option<String>

PodGroupReplicaKey specifies the replica key of the PodGroup to which this Pod belongs. It is used to distinguish pods belonging to different replicas of the same pod group. The pod group policy is applied separately to each replica. When set, it must be a DNS label.

+optional

Implementations

Source

impl WorkloadReference

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn pod_group(&self) -> &str

Returns the value of pod_group, or the default value if pod_group is unset.

pub fn pod_group_replica_key(&self) -> &str

Returns the value of pod_group_replica_key, or the default value if pod_group_replica_key is unset.