pub struct NetworkDeviceData {
pub interface_name: Option<String>,
pub ips: Vec<String>,
pub hardware_address: Option<String>,
}Expand description
NetworkDeviceData provides network-related details for the allocated device. This information may be filled by drivers or other components to configure or identify the device within a network context.
Fields
interface_name: Option<String>InterfaceName specifies the name of the network interface associated with the allocated device. This might be the name of a physical or virtual network interface being configured in the pod.
Must not be longer than 256 characters.
+optional +k8s:optional +k8s:maxLength=256
ips: Vec<String>IPs lists the network addresses assigned to the device’s network interface. This can include both IPv4 and IPv6 addresses. The IPs are in the CIDR notation, which includes both the address and the associated subnet mask. e.g.: “192.0.2.5/24” for IPv4 and “2001:db8::5/64” for IPv6.
+optional +listType=atomic +k8s:optional +k8s:listType=atomic +k8s:unique=set +k8s:maxItems=16
hardware_address: Option<String>HardwareAddress represents the hardware address (e.g. MAC Address) of the device’s network interface.
Must not be longer than 128 characters.
+optional +k8s:optional +k8s:maxLength=128
Implementations
Sourceimpl NetworkDeviceData
impl NetworkDeviceData
Sourcepub fn interface_name(&self) -> &str
pub fn interface_name(&self) -> &str
Returns the value of interface_name, or the default value if interface_name is unset.
Sourcepub fn hardware_address(&self) -> &str
pub fn hardware_address(&self) -> &str
Returns the value of hardware_address, or the default value if hardware_address is unset.