pub struct VolumeError {
pub time: Option<Time>,
pub message: Option<String>,
pub error_code: Option<i32>,
}Expand description
VolumeError captures an error encountered during a volume operation.
Fields
time: Option<Time>time represents the time the error was encountered. +optional
message: Option<String>message represents the error encountered during Attach or Detach operation. This string may be logged, so it should not contain sensitive information. +optional
error_code: Option<i32>errorCode is a numeric gRPC code representing the error encountered during Attach or Detach operations.
This is an optional, beta field that requires the MutableCSINodeAllocatableCount feature gate being enabled to be set.
+featureGate=MutableCSINodeAllocatableCount +optional
Implementations
Sourceimpl VolumeError
impl VolumeError